@@ -24,7 +24,16 @@
 #' silhouette(kmeans_fit, dists = dists)
 #' @export
 silhouette <- function(object, new_data = NULL, dists = NULL,
-                        dist_fun = Rfast::Dist) {
+                       dist_fun = Rfast::Dist) {
+  if (inherits(object, "cluster_spec")) {
+    rlang::abort(
+      paste(
+        "This function requires a fitted model.",
+        "Please use `fit()` on your cluster specification."
+      )
+    )
+  }
+
   preproc <- prep_data_dist(object, new_data, dists, dist_fun)
 
   clust_int <- as.integer(gsub("Cluster_", "", preproc$clusters))
@@ -35,7 +44,8 @@ silhouette <- function(object, new_data = NULL, dists = NULL,
     res <- tibble::tibble(
       cluster = preproc$clusters,
       neighbor = factor(rep(NA_character_, length(preproc$clusters)),
-                        levels = levels(preproc$clusters)),
+        levels = levels(preproc$clusters)
+      ),
       sil_width = NA_real_
     )
     return(res)
@@ -90,6 +100,17 @@ silhouette_avg <- new_cluster_metric(
   direction = "zero"
 )
 
+#' @export
+#' @rdname silhouette_avg
+silhouette_avg.cluster_spec <- function(object, ...) {
+  rlang::abort(
+    paste(
+      "This function requires a fitted model.",
+      "Please use `fit()` on your cluster specification."
+    )
+  )
+}
+
 #' @export
 #' @rdname silhouette_avg
 silhouette_avg.cluster_fit <- function(object, new_data = NULL, dists = NULL,
