@@ -1,32 +1,77 @@
-stats_kmeans_predict <- function(object, new_data, prefix = "Cluster_") {
-  res <- object$centers[unique(object$cluster), , drop = FALSE]
-  res <- flexclust::dist2(res, new_data)
-  res <- apply(res, 2, which.min)
-  res <- paste0(prefix, res)
-  factor(res)
+make_predictions <- function(x, prefix, n_clusters) {
+  levels <- seq_len(n_clusters)
+  factor(x, levels = levels, labels = paste0(prefix, levels))
 }
 
-clusterR_kmeans_predict <- function(object, new_data, prefix = "Cluster_") {
+.k_means_predict_stats <- function(object, new_data, prefix = "Cluster_") {
+  res <- object$centers
+  res <- flexclust::dist2(res, new_data)
+  res <- apply(res, 2, which.min)
+
+  make_predictions(res, prefix, length(object$size))
+}
+
+.k_means_predict_ClusterR <- function(object, new_data, prefix = "Cluster_") {
   clusters <- predict(object, new_data)
   n_clusters <- length(object$obs_per_cluster)
 
-  reorder_clusts <- order(union(unique(clusters), seq_len(n_clusters)))
-  names <- paste0(prefix, seq_len(n_clusters))
-  res <- names[reorder_clusts][clusters]
-
-  factor(res)
+  make_predictions(clusters, prefix, n_clusters)
 }
 
-stats_hier_clust_predict <- function(object, new_data, ..., prefix = "Cluster_") {
+.k_means_predict_clustMixType <- function(object, new_data, prefix = "Cluster_") {
+  clusters <- predict(object, new_data)$cluster
+  n_clusters <- length(object$size)
+
+  make_predictions(clusters, prefix, n_clusters)
+}
+
+.k_means_predict_klaR <- function(object, new_data, prefix = "Cluster_",
+                                  ties = c("first", "last", "random")) {
+  ties <- rlang::arg_match(ties)
+
+  modes <- object$modes
+  n_modes <- nrow(modes)
+
+  clusters <- integer(nrow(new_data))
+
+  modes <- as.matrix(modes)
+  new_data <- as.matrix(new_data)
+
+  for (i in seq_along(clusters)) {
+    misses <- rowSums(new_data[rep(i, n_modes), ] != modes)
+
+    which_min <- which(misses == min(misses))
+
+
+    if (length(which_min) == 1) {
+      clusters[i] <- which_min
+    } else {
+      clusters[i] <- switch(
+        ties,
+        first = which_min[1],
+        last = which_min[length(which_min)],
+        random = sample(which_min, 1)
+      )
+    }
+  }
+
+  make_predictions(clusters, prefix, n_modes)
+}
+
+.hier_clust_predict_stats <- function(object, new_data, ..., prefix = "Cluster_") {
   linkage_method <- object$method
 
   new_data <- as.matrix(new_data)
 
   training_data <- as.matrix(attr(object, "training_data"))
-  clusters <- extract_cluster_assignment(object, ..., prefix = prefix)
+  clusters <- extract_cluster_assignment(
+    object,
+    ...,
+    prefix = prefix,
+    call = call("predict")
+  )
 
   if (linkage_method %in% c("single", "complete", "average", "median")) {
-
     ## complete, single, average, and median linkage_methods are basically the
     ## same idea, just different summary distance to cluster
 
@@ -48,7 +93,6 @@ stats_hier_clust_predict <- function(object, new_data, ..., prefix = "Cluster_")
       dplyr::select(-.cluster) %>%
       map_dbl(which.min)
   } else if (linkage_method == "centroid") {
-
     ## Centroid linkage_method, dist to center
 
     cluster_centers <- extract_centroids(object) %>% dplyr::select(-.cluster)
@@ -56,7 +100,6 @@ stats_hier_clust_predict <- function(object, new_data, ..., prefix = "Cluster_")
 
     pred_clusts_num <- apply(dists_means, 1, which.min)
   } else if (linkage_method %in% c("ward.D", "ward", "ward.D2")) {
-
     ## Ward linkage_method: lowest change in ESS
     ## dendrograms created from already-squared distances
     ## use Ward.D2 on these plain distances for Ward.D
@@ -69,9 +112,9 @@ stats_hier_clust_predict <- function(object, new_data, ..., prefix = "Cluster_")
     d_means <- map(
       seq_len(n_clust),
       ~ t(
-          t(training_data[clusters$.cluster == cluster_names[.x], ]) -
-            cluster_centers[.x, ]
-        )
+        t(training_data[clusters$.cluster == cluster_names[.x], ]) -
+          cluster_centers[.x, ]
+      )
     )
 
     d_new_list <- map(
@@ -107,5 +150,5 @@ stats_hier_clust_predict <- function(object, new_data, ..., prefix = "Cluster_")
   }
   pred_clusts <- unique(clusters$.cluster)[pred_clusts_num]
 
-  return(factor(pred_clusts))
+  pred_clusts
 }
